

* This code generates the unemployment simulation in order to match a target unemployment rate change
* We consider that in a given country households can only move in OR out of employment, but we cannot have movements in both directions in the same country
* Therefore, for countries in which unemployment has increased, there will be only movements into unemployment
* For those in which unemployment has decreased, there will be only movements out of employment

* -------------------------------------------------------

*cd "U:\Slacalek\research\HFCS\HFCSupdate\programs"

set more off
clear
clear matrix
*#delimit;
set mem 3000m
set matsize 155
program drop _all
discard
*----------------------------------------------------------------------;
do setPath
local basePath "$basePath"
local stataPath "$stataPath"
local logPath "`stataPath'"
local dataPath "`basePath'\data"
global dataPath "`dataPath'"
adopath + "`stataPath'"

cd "`basePath'\programs\unemploymentSimulation"

use "`dataPath'\data_unemp_simulation.dta", clear

local simul = $noOfSimulations
* # of simulations
* -------------------------------------------------------

* Generate predicted employment status
* Probits are run country by country

egen countryid = group(sa0100)
gen job_hat = .
forvalues i =1(1)15 {
probit job dhgenderh college highschool age2 age3 age4 age5 age6 single dhchildrendependent if countryid == `i'
predict job_hat_aux
replace job_hat = job_hat_aux if countryid == `i' 
drop job_hat_aux
}
* There are a few obs for FI which no prediction is made since education is missing, just assign mean.
sum job_hat if sa0100 == "FI"
replace job_hat = r(mean) if job_hat == .

* ushock is the sector "rebalancing"
replace ushock = 0 if ushock == .
replace job_hat = job_hat + ushock

replace job_hat = . if job == .

label variable job_hat "Predicted employment probability, continuous"


* Generate predicted labor incomes (they will be used for replacing income of those moving from unemployment to employment)
* Use two step Heckman selection model (ML estimation was giving convergence problems, also # of active members in hh as exclusion restriction gave problems) 
* Weights are not used in the regression (they cannot be used with the two step heckman, and it is not clear conceptually if they should be used)
gen laborincome_hat = .
forvalues i =1(1)15 {
heckman laborincome dhgenderh college highschool age2 age3 age4 age5 age6  if countryid == `i', select(job = dhgenderh college highschool age2 age3 age4 age5 age6 single dhchildrendependent) twostep
predict laborincome_hat_aux
replace laborincome_hat = laborincome_hat_aux if countryid == `i' 
drop laborincome_hat_aux
}
* There are a few obs for FI which no prediction is made since education is missing, just assign mean.
sum laborincome_hat if sa0100 == "FI"
replace laborincome_hat = r(mean) if laborincome_hat == .

label variable laborincome_hat "Predicted labor income"

* -------------------------------------------------------

* SIMULATION

* -------------------------------------------------------

forvalues j = 1(1)`simul' {

gen ind = 0 if job == 0
replace ind = 1 if ind == .

* Generate a random draw in the [0,1] space from a uniform distr.
gen rnd_jobprob = runiform()

* Compute the distance to the threshold. 
gen temp = (job_hat-rnd_jobprob)

* Step 2: identify the "marginal" agents
*gen ind=(temp>0)

* Sort according to marginal probabilites
sort sa0100 ind temp
by sa0100 ind: gen marg_rank =_n
replace marg_rank=. if ind==0
* a rank of 1 indicates that this is the next agent to drop out of a job 

* Carry out simulation

* USE IF WE DONT WANT TO DEAL WITH COUNTRIES WHERE UNEMPLOYMENT HAS GONE DOWN
****************************************************
*replace  ScaleF_UT = 1 if ScaleF_UT < 1
****************************************************

gen job_aftershock=job
forvalues i = 1(1)15 {

sum job [aweight=hw0010] if countryid == `i'
scalar unemp0 = (1 - r(mean))

sum ScaleF_UT if countryid == `i'
scalar unemp1 = unemp0*r(mean)

egen totalW = total(hw0010) if job != . & countryid == `i'
gen aux1 = hw0010/totalW
gen aux2 = sum(aux1)
gen aux3 = 0 if aux2 < unemp1

* Households moving into unemployment
replace job_aftershock=0 if aux3==0 & countryid == `i'

* Households moving out of unemployment
replace job_aftershock=1 if job == 0 & aux3==. & countryid == `i'

drop totalW aux1 aux2 aux3

}


* INCOME REPLACEMENT

gen di2000_NEW = di2000

gen di1100_NEW = di1100
gen di1200_NEW = di1200
gen di1600_NEW = di1600

* Replace the salary of those who have been hit by unemployment using the replacement rate
* Note that there are cases where the laborincome is 0 and thus no replacement takes place

replace di2000_NEW = di2000_NEW - laborincome if job == 1 & job_aftershock == 0
replace di2000_NEW = di2000_NEW + replrate/100*laborincome if job == 1 & job_aftershock == 0

replace di1100_NEW = di1100_NEW - wages if job == 1 & job_aftershock == 0
replace di1100_NEW = di1100_NEW + replrate/100*wages if job == 1 & job_aftershock == 0

replace di1200_NEW = di1200_NEW - selfemployedincome if job == 1 & job_aftershock == 0
replace di1200_NEW = di1200_NEW + replrate/100*selfemployedincome if job == 1 & job_aftershock == 0


* Replace the salary of those who have move out of unemployment by their predicted labor income 
* We substract unemployment benefits of the household head first and then add predicted labor income of household head

replace di2000_NEW = di2000_NEW - unemp_benefits if job == 0 & job_aftershock == 1
replace di2000_NEW = di2000_NEW + laborincome_hat if job == 0 & job_aftershock == 1

replace di1600_NEW = di1600_NEW - unemp_benefits if job == 0 & job_aftershock == 1
replace di1600_NEW = di1600_NEW + laborincome_hat if job == 0 & job_aftershock == 1

* Store results of each simulation
gen di2000_NEW_`j' = di2000_NEW
gen di1100_NEW_`j' = di1100_NEW
gen di1200_NEW_`j' = di1200_NEW
gen di1600_NEW_`j' = di1600_NEW
drop ind rnd_jobprob temp marg_rank job_aftershock di2000_NEW di1100_NEW di1200_NEW di1600_NEW

}

egen di2000_NEW = rowmean(di2000_NEW_*)
drop di2000_NEW_*

egen di1100_NEW = rowmean(di1100_NEW_*)
drop di1100_NEW_*

egen di1200_NEW = rowmean(di1200_NEW_*)
drop di1200_NEW_*

egen di1600_NEW = rowmean(di1600_NEW_*)
drop di1600_NEW_*
*********************************************************************
rename di2000_NEW di2000_unempSimul
rename di1100_NEW di1100_unempSimul
rename di1200_NEW di1200_unempSimul
rename di1600_NEW di1600_unempSimul

keep id  di2000_unempSimul di1100_unempSimul di1200_unempSimul di1600_unempSimul 
*keep id  di2000_unempSimul hw0010 sa0100
sort id
save "`dataPath'\outputUnempSimul.dta", replace

