
* Unemployment simulation at the individual level;

* This code generates the unemployment simulation in order to match a target unemployment rate change
* We consider that in a given country individuals can only move in OR out of employment, but we cannot have movements in both directions in the same country
* Therefore, for countries in which unemployment has increased, there will be only movements into unemployment
* For those in which unemployment has decreased, there will be only movements out of employment

******************
* IMPORTANT NOTE: We have information on the CURRENT employment status of the individual and information of the income of the LAST 12 MONTHS. This creates a problem in our simulation when the current
* employment status does not match witht the type of income reported. For example, we might have an indidivual who is employed and last year only received unemployment income. If he receives a shock to
* employment, his unemployment benefits will be 0 (since we apply the replacement rate to a quantity of  0) and his income will also be 0. This is an extreme case, in the intermediate casees where the 
* individual reports both employment income and unemployment benefits, he will be assigned some income after moving to unemployment. 
* The errors coming from this situation should be very few cases so we are just leaving it like this. We could create an alternative indicator of employment by using the information on the income received in 
* the last 12 months to clasify the individual as employed or unemployed. The problem with this is that in many cases both types of income are reported.
******************

* The final output of this program is a new income variable di2000. The different income components are not comparable when using the regular sum command because of the tratment of 0s and missings.

*****************

set more off

* -------------------------------------------------------
cd "U:\Ampudia\HFCSupdate\UnEmploymentSimul"
* -------------------------------------------------------


timer on 1

forvalues im = 1(1)5 {

use data_unemp_simulation_IND.dta, clear

keep if im0100 == `im'

* We just consider households member above 16 years old
keep if ra0300 >= 16

* Generate predicted employment status
* Probits are run country by country

egen countryid = group(sa0100)
gen job_hat = .
forvalues i =1(1)15 {
probit job gender college highschool age2 age3 age456 single children if countryid == `i'
predict job_hat_aux
replace job_hat = job_hat_aux if countryid == `i' 
drop job_hat_aux
}
* There are a few obs for FI which no prediction is made since education is missing, just assign mean.
sum job_hat if sa0100 == "FI"
replace job_hat = r(mean) if job_hat == . & sa0100 == "FI"

* In the case of Cyprus, there is no info on marital status, gender or education for all members different than the reference person. For this reason, I run a different probit (using less info) for these individuals
probit job age2 age3 age456 children if sa0100 == "CY" & job_hat == .
predict job_hat_aux
replace job_hat = job_hat_aux if sa0100 == "CY" & job_hat == . 
drop job_hat_aux

* ushock is the sector "rebalancing" (this info is not available for all household members)
replace ushock = 0 if ushock == .
replace job_hat = job_hat + ushock

replace job_hat = . if job == .

label variable job_hat "Predicted employment probability, continuous"


* Generate predicted labor incomes (they will be used for replacing income of those moving from unemployment to employment)
* Use two step Heckman selection model (ML estimation was giving convergence problems, also # of active members in hh as exclusion restriction gave problems) 
* Weights are not used in the regression (they cannot be used with the two step heckman, and it is not clear conceptually if they should be used)
gen laborincome_hat = .
forvalues i =1(1)15 {
heckman laborincome gender college highschool age2 age3 age456  if countryid == `i', select(job = gender college highschool age2 age3 age456 single children) twostep
predict laborincome_hat_aux
replace laborincome_hat = laborincome_hat_aux if countryid == `i' 
drop laborincome_hat_aux
}
* There are a few obs for FI which no prediction is made since education is missing, just assign mean.
sum laborincome_hat if sa0100 == "FI"
replace laborincome_hat = r(mean) if laborincome_hat == . & sa0100 == "FI"

* In the case of Cyprus, there is no info on marital status, gender or education for all members different than the reference person. For this reason, I run a different heckman (using less info) for these individuals
heckman laborincome age2 age3 age456 if sa0100 == "CY" & laborincome_hat == ., select(job = age2 age3 age456 children) twostep
predict laborincome_hat_aux
replace laborincome_hat = laborincome_hat_aux if sa0100 == "CY" & laborincome_hat == .
drop laborincome_hat_aux

label variable laborincome_hat "Predicted labor income"

* -------------------------------------------------------

* SIMULATION

* -------------------------------------------------------

local simul 5

forvalues j = 1(1)`simul' {

gen ind = 0 if job == 0
replace ind = 1 if ind == .

* Generate a random draw in the [0,1] space from a uniform distr.
gen rnd_jobprob = runiform()

* Compute the distance to the threshold. 
gen temp = (job_hat-rnd_jobprob)

* Make sure households above the 99 percentile of income are not affected by the simulation
*_pctile laborincome [pweight=hw0010], n(100)
*gen aux1 = 1 if laborincome >= r(r99) & laborincome != .
*replace temp = 1 if aux1 == 1
*drop aux1

* Sort according to marginal probabilites
sort sa0100 ind temp
by sa0100 ind: gen marg_rank =_n
replace marg_rank=. if ind==0
* a rank of 1 indicates that this is the next agent to drop out of a job 

* Carry out simulation

* USE IF WE DONT WANT TO DEAL WITH COUNTRIES WHERE UNEMPLOYMENT HAS GONE DOWN
****************************************************
*replace  ScaleF_UT = 1 if ScaleF_UT < 1
****************************************************

gen job_aftershock=job
forvalues i = 1(1)15 {

sum job [aweight=hw0010] if countryid == `i'
scalar unemp0 = (1 - r(mean))

sum ScaleF_UT if countryid == `i'
scalar unemp1 = unemp0*r(mean)

egen totalW = total(hw0010) if job != . & countryid == `i'
gen aux1 = hw0010/totalW
gen aux2 = sum(aux1)
gen aux3 = 0 if aux2 < unemp1

* Individuals moving into unemployment
replace job_aftershock=0 if aux3==0 & countryid == `i'

* Individuals moving out of unemployment
replace job_aftershock=1 if job == 0 & aux3==. & countryid == `i'

drop totalW aux1 aux2 aux3

}


* INCOME REPLACEMENT


gen pg0110_NEW = pg0110
replace pg0110_NEW = 0 if pg0110_NEW == .
gen pg0210_NEW = pg0210
replace pg0210_NEW = 0 if pg0210_NEW == .
gen pg0510_NEW = pg0510
replace pg0510_NEW = 0 if pg0510_NEW == .

* Replace the salary of those who have been hit by unemployment using the replacement rate
* Note that there are cases where the laborincome is 0 and thus no replacement takes place

replace pg0110_NEW = 0 if job == 1 & job_aftershock == 0
replace pg0510_NEW = pg0510_NEW + replrate/100*wages if job == 1 & job_aftershock == 0

replace pg0210_NEW = 0 if job == 1 & job_aftershock == 0
replace pg0510_NEW = pg0510_NEW + replrate/100*selfemployedincome if job == 1 & job_aftershock == 0



* Replace the salary of those who have moved out of unemployment by their predicted labor income 
* We substract unemployment benefits first and then add predicted labor income (note that we always allocate the new income to employee income, never to self-employed income)

replace pg0510_NEW = 0 if job == 0 & job_aftershock == 1
replace pg0110_NEW = pg0110_NEW + laborincome_hat if job == 0 & job_aftershock == 1



*replace pg0110_NEW = . if pg0110_NEW == 0
*replace pg0210_NEW = . if pg0210_NEW == 0
*replace pg0510_NEW = . if pg0510_NEW == 0

* Store results of each simulation
gen pg0110_NEW_`j' = pg0110_NEW
gen pg0210_NEW_`j' = pg0210_NEW
gen pg0510_NEW_`j' = pg0510_NEW
gen job_aftershock_`j' = job_aftershock
drop ind rnd_jobprob temp marg_rank job_aftershock pg0110_NEW pg0210_NEW pg0510_NEW

}


* Average across simulations
egen pg0110_NEW = rowmean(pg0110_NEW_*)
drop pg0110_NEW_*

egen pg0210_NEW = rowmean(pg0210_NEW_*)
drop pg0210_NEW_*

egen pg0510_NEW = rowmean(pg0510_NEW_*)
drop pg0510_NEW_*

egen job_aftershock = rowmean(job_aftershock_*)
drop job_aftershock_*


* Sum the different income components for all the individuals of a household
bysort id: egen di1100_NEW = total(pg0110_NEW)
bysort id: egen di1200_NEW = total(pg0210_NEW)
bysort id: egen di1610_NEW = total(pg0510_NEW)

keep if ra0100 == 1

keep id di1100_NEW di1200_NEW di1610_NEW job_aftershock

* Keeping only one observation per household (and implicate)
*duplicates drop

save results_`im'.dta, replace

use "U:\Ampudia\HFCS\data\D_compl.dta", clear

keep if im0100 == `im'

merge m:1 id using results_`im'.dta

tab _merge
drop _merge


gen aux1 = di1100
replace aux1 = 0 if aux1 == .
gen aux2 = di1200
replace aux2 = 0 if aux2 == .
gen aux3 = di1610
replace aux3 = 0 if aux3 == .

gen aux4 = di1100_NEW
replace aux4 = 0 if aux4 == .
gen aux5 = di1200_NEW
replace aux5 = 0 if aux5 == .
gen aux6 = di1610_NEW
replace aux6 = 0 if aux6 == .


gen di2000_NEW = di2000 - aux1 - aux2 - aux3 + aux4 + aux5 + aux6
drop aux*


save results_`im'.dta, replace

}


use results_1.dta, clear
forvalues im = 2(1)5 {
append using results_`im'.dta
}

timer off 1

timer list 1
timer clear 1
